@@ -1,6 +1,7 @@
 from typing import Callable
 
 from starlette.middleware.base import BaseHTTPMiddleware
+from starlette.requests import Request
 
 
 class PgMiddleware(BaseHTTPMiddleware):
@@ -12,7 +13,7 @@ class PgMiddleware(BaseHTTPMiddleware):
 
         self.glove = glove
 
-    async def dispatch(self, request, call_next):
+    async def dispatch(self, request: Request, call_next):
         if self.check and not self.check(request):
             return await call_next(request)
         else:
